* Master Compile Do File
* Making move matter; Performance-Based Postings

/*********************************************************

	OVERVIEW
	This do file is the first step in the data cleaning / processing pipeline. It takes
	data from its raw fundamental form and cleans and compiles it into something that can
	be combined with treatment and other analysis variables.
	
***********************************************************/


clear all
set more off
version 14.0

**************************************
* Set-up

// Set up the directory global. This will be shared across do files. 

// cap cd *FILL IN HERE*
cap cd "D:\temp\MBTP"

global PAKTAX2_ANALYSIS = "`c(pwd)'"
global PAKTAX2_RANDOMIZATION = "${PAKTAX2_ANALYSIS}/Data/Randomization"

* Globals for randomization and analysis. Leave this fixed. These globals are referred to in the sub do files.

set obs 1
g temp1=c(current_date)
g temp2=date(temp1,"DMY")
g temp3=year(temp2)
tostring temp3, replace
g year=substr(temp3,3,2)
g month=month(temp2)
g day=day(temp2)
tostring month day, replace
replace month="0"+month if length(month)==1
replace day="0"+day if length(day)==1
global DATE = year+month+day
drop temp* month day year
display $DATE
	
****************************************************************  
* CLEAN RAW DATA (FROM RAW TO CLEANED DATA)
****************************************************************  

** Crosswalking - All administrative data 

	do "${PAKTAX2_ANALYSIS}/Data/Do Files/Administrative Data/Make Keys.do"
	do "${PAKTAX2_ANALYSIS}/Data/Do Files/Administrative Data/Crosswalk to Present - Analysis.do"
	do "${PAKTAX2_ANALYSIS}/Data/Do Files/Administrative Data/Crosswalk to TP Randomization.do"

** Compile Preferences data

	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Cleaning/130815 Preference Data Cleaning" 
	
****************************************************************  
* RANDOMIZATION
* NOTE: each file will ask you for a number chosen by ballot. We have listed the number to enter for reach file below
**************************************************************** 

** Year 1 Randomization 

	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 1/130725Lahore_Pilot_Ballot.do" // 150
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 1/130728Multan_Pilot_Ballot.do" // 51135
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 1/130725Lahore_Main_Ballot.do" // 1170000
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 1/130728Lahore_Assign_Treatment_Ballot.do" // 2100	
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 1/130728OtherDivisions_Main_Ballot.do" // 606
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 1/130728OtherDivisions_Assign_Treatment_Ballot.do" // 17921

** Cleaning for Year 2 Randomization 
	
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 2/140702 Create Dataset for Ballot in Year 2.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 2/140713 Create Dataset for New Groups Ballot.do" 
	
** Year 2 Randomization 
	
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 2/140702 Year2 Ballot 1 (For Treated Groups).do" // 500060
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 2/140723 Excluded Divisions and Control Groups Ballot.do" // 125450
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Randomization\Year 2/140821 Year2 Ballot 2 (For Control Groups).do" // 391

** Cleaning Output from Randomization
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Cleaning\Treatment Inspectors List\Year 1/131123 treatment inspector list.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Cleaning\Treatment Inspectors List\Year 2/Master Year 2 Ballot Cleaning.do" 	
	
****************************************************************  
* Randomization Inference (RI) input
****************************************************************  

/* Run 2,000 counterfactual randomizations. To be used to compute RI p-values.
   It is recommended to run this code just once. 
   
   do "${PAKTAX2_ANALYSIS}/Data\Do Files\RI/Ballot" 
																			*/
	
