* Master Do File - Analysis
* Making move matter; Performance-Based Postings

/*********************************************************

	OVERVIEW
	Transforms Cleaned to Coded data.
	Generates tables in the paper.
	
***********************************************************/

clear all
set more off
version 14.0

**************************************

* Set-up

* install 'center' and 'tabmiss' and `grc1leg' command
cap ssc install center
cap net install tabmiss
cap net install grc1leg.pkg

// Setting up the directory global. This will be shared across do files. 

// cap cd *FILL IN HERE*
cap cd "D:\Dropbox (MIT)\Research-Active\Pakistan Property Tax Project 2\TP Analysis\MBTP"

global PAKTAX2_ANALYSIS = "`c(pwd)'"
global TP_ANALYSIS = "`c(pwd)'/TP Analysis/"
global TP_TABLE_OUTPUT = "`c(pwd)'/TP Analysis/output"
global TP_PAPER_OUTPUT = "`c(pwd)'/TP Analysis/output/Paper"
global analysis_filepath = "${TP_ANALYSIS}/Do Files/Paper"

***************************************

*******************
* PREPARE CODED DATA 
*******************

** Prepare Year 1 data
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Data prep/150525 Analysis Dataset Cleaning - Year 1.do"
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Data prep/150525 Analysis Dataset Cleaning - Year 1 FULL SAMPLE.do"
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Time in Circle as of Y2 Q3.do"
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Y2 Q1 and Y3 Q1 Demand Data.do"

** Prepare Preferences data
	do "${PAKTAX2_ANALYSIS}/Data/Do Files/Data prep/Baseline Preferences data prep.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Y1 Preferences data prep.do" 
	
** Prepare Basic simulations data
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Competitiveness analysis data prep.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Basic simulation results prep.do" 

** Y1 Movements
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Y1 Movement Dummies.do" 

** Y1 Ranks
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/140821 Calculate Q4 Ranks Demand UPDATED.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/140821 Calculate Q4 Ranks Recovery UPDATED.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Demand Ranks Q4 2014 control inspectors.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Recovery Ranks Q4 2014 control inspectors.do" 

** Transfers
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Inspectors after Y1 transfers.do" 
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Preferences_treatment.do"
	
** Prepare Year 2 data
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/150610 Analysis Dataset Cleaning Year 2.do"
	do "${PAKTAX2_ANALYSIS}/Data\Do Files/Data prep/Analysis Dataset with Lags.do"
	
** Base growth predictions and Simulation inputs
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Transfer simulations/base_growth_predictions.do" // Table A7 & Figure A1
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Transfer simulations/prepare_sim_input.do"

** Prepare Simulation output
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Transfer simulations/average_effort_multipleiters.do"
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Transfer simulations/average_effort_multipleiters_up_down.do"
	do "${PAKTAX2_ANALYSIS}/Data\Do Files\Transfer simulations/average_effort_robustness.do"

*******************
* TABLES AND FIGURES
*******************

	cap cd "${TP_ANALYSIS}"

	* 1 Summary stats (Table 1)
	do "$analysis_filepath/summary_stats.do" // Requires Python to fix decimal points in "Observations" column

	* 2 Basic treatment effect (Tables 3, A3 & A4)
	do "$analysis_filepath/basic_treatment_effect_rand_inference.do"
	do "$analysis_filepath/basic_treatment_effect_rand_inference_controls.do"
	
	* 3 Heterogeneity  (Tables 4, A5, A6, A9 & A10)
	do "$analysis_filepath/hetero_competitiveness_eqeffort_paper.do"
	do "$analysis_filepath/hetero_competitiveness_eqeffort_paper_UP_DOWN_ROB.do"
	do "$analysis_filepath/hetero_competitiveness_eqeffort_paper_ROBUSTNESS.do"

	* 4 Allocation (Table 5 & A11)
	do "$analysis_filepath/allocation_preferences_tables_paper.do"

	* 5 Dynamics (Table 6)
	do "$analysis_filepath/interaction_complete_rand_inference.do"
	
	* 6 Baseline preferences - Distributions (Figure 1)
	do "$analysis_filepath/baseline_preferences_histograms.do"
	do "$analysis_filepath/correlation_analysis_paper.do"

	* 7 Histograms (Figure 3)
	do "$analysis_filepath/simulation_histograms.do"
	do "$analysis_filepath/simulation_histograms_avgeffort.do" 
	
	* 8 Treatment effect graph (Figure 4)
	do "$analysis_filepath/basic_treatment_effect_graphs.do"

	* 9 Balance table (Table A1)
	do "$analysis_filepath/balance_table_rand_pooled.do" 

	* 10 Margins of impact (Table A2)
	do "$analysis_filepath/margins_of_impact_paper.do" 

	* 11 Relationship between movements and performance (Table A11)
	do "$analysis_filepath/inspector_happiness_paper.do"

	* 12 Preferences & continuing status (Table A12)
	do "$analysis_filepath/y1_preferences_rand_inference.do"

	* 13 How does the serial dictatorship change allocations? (Table A13)
	do "$analysis_filepath/time_in_circle_rand_inference.do"

	* 14 Predicting movements (Table A14 & Table A15)
	do "$analysis_filepath/switching_cost.do"

	* 15 Uniqueness of alpha (Figure A2)
	do "$analysis_filepath/plotalpha_paper.do" 

	* 16 Uniqueness of eq effort (Figure A3)
	do "$analysis_filepath/uniqueness_eqalpha_paper.do"
