* Transfer and Posting Treatment Individuals List
* Obeid
* 23rd Nov 2013
******************************************************

* I. Workspace
* Randomization outputs exist as 4 different data sets. Lahore pilot, Multan pilot, Lahore non-pilot, Non-Lahore non-pilot
* Merge them together to get a comprehensive list with circle codes and treatment lists

* II. Merging in HR status from HR files
* HR at ballot not accurate for all circles. Updated information saved in HR file

* III. Double Checking with Q1 HR
* Some further corrections made in HR.

* IV. Issues

* V. Output
* Generating a comprehensive final list for all calculations
***************************************************************************************************************************

***************
* I. Workspace
***************
clear
set more off
pause on
cap cd "$PAKTAX2_ANALYSIS"

*** Lahore Pilot
u "Data\Randomization\Output\Year 1\130726 Lahore PILOT Transfers Randomization Output 150.dta",clear
gen ranking_method="RECOVERY"
gen district="LAHORE"
keep division_id division_name circle_id group treatment lottery group ranking_method district
keep if treatment !=""
tempfile lahorepilot
sa `lahorepilot'

*** Multan Pilot
u "Data\Randomization\Output\Year 1\130803 Multan PILOT Transfers Randomization Output 51135.dta",clear
gen ranking_method="RECOVERY"
keep division_id division_name district circle_id group treatment lottery group ranking_method
keep if treatment !=""
tempfile multanpilot
sa `multanpilot'

*** Lahore Non-pilot
use "Data\Randomization\Output\Year 1\130803 Lahore Assign Treatment Transfers Randomization Output 2100.dta",clear
gen district="LAHORE"
keep division_id division_name circle_id group treatment lottery group ranking_method district
keep if treatment !=""
tempfile lahorerest
sa `lahorerest'

*** Multan Non-pilot
use "Data\Randomization\Output\Year 1\130829 Other Divisions Assign Treatment Transfers Randomization Output 17921.dta",clear
keep division_id district division_name circle_id group treatment lottery group ranking_method
keep if treatment !=""
tempfile multanrest
sa `multanrest'

*** Appending 
u `lahorepilot',clear
append using `multanpilot'
append using `lahorerest'
append using `multanrest'
gen partition_id=division_id
replace partition_id=5 if division_id==6
gen partition_name=division_name
replace partition_name="LAHORE" if inlist(partition_name,"LAHORE A","LAHORE B")
sort partition_id group
tempfile treat
sa `treat'

***********************
* II. Merging HR Status
***********************

import excel "Data/Raw Data/Current HR Confirmation\130630 HR Verification Q4-Ballot\130729 Non-Lahore Ballot HR Verification (HR ID).xlsx", sheet("130729 June 30th HR") firstrow clear
keep circle_id hr_id ins_1_ac
sort circle_id
tempfile hr
sa `hr'

u `treat', clear
sort circle_id
merge 1:1 circle_id using `hr'
assert _m!=1
keep if _m==3
drop _merge treatment lottery_group
order partition_id partition_name division_id division_name district circle_id  hr_id ins_1_ac
sort partition_id group circle_id

***********************
* IV. Issues
***********************

**Flag = 1 PEOPLE WHO HAVE NOT BEET TRAINED
gen flag=.
replace flag = 1 if hr_id==41010 
replace flag = 1 if hr_id==40813 
replace flag = 1 if hr_id==40945
replace flag = 1 if hr_id==81036
replace flag = 1 if hr_id==81066 

**Flag = 2 CIRCLE DIDNT EXIST
replace flag = 2 if circle_id==306500

**Flag = 3 CIRCLE UNDER LITIGATION
replace flag = 3 if circle_id==1101300

**Flag = 4 CIRCLE DATA ISSUES
replace flag = 4 if inlist(circle_id,503300,503400)

label define flag 1 "Not Trained" 2 "New Circle" 3 "Litigation" 4 "Data Issues"
label values flag flag

**Missing preferences
preserve
	u "Data/Cleaned Data\Preference Data\Compiled Preference Data.dta", replace
	keep if treatment==1
	levelsof own_hr_id if ranking==. ,local(misslist)
restore
gen miss_pref=.
foreach id in `misslist' {
replace miss_pref=1 if hr_id==`id'
}

***********************
* V. Output
***********************
save "Data/Raw Data/Current HR Confirmation\131124 Stage II Treatment Staff.dta",replace
