clear all
version 12

/*
Outline:
0. Set workspace
1. Create sample
2. Allocate circles into ONE PILOT GROUP IN LAHORE 
3. Balance checks  
4. Save files and display 
*/

**************************************************************************************************

cap cd "$PAKTAX2_RANDOMIZATION"

************************************************************************************************

*1. Create sample

use "Data for Ballot\Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL",clear 
qui count
local initial_total_obs `r(N)' 

*Keep only eligible circles in Lahore 
keep if partition_id  == 5  // Keep Lahore A, Lahore B only  
drop if pilot_exclude == 1 // drop any circle that is pilot ineligible 

qui count
local pilot_total_obs `r(N)'

assert stratum_id != . 

**************************************************************************************************

*2. Allocate circles into ONE PILOT GROUP IN LAHORE  

**Select seed for pilot ballot
sort stratum_id circle_id 

noisily display "Enter the number chosen by ballot: " _request(PILOTSEEDINPUT)
display "$PILOTSEEDINPUT"
set seed $PILOTSEEDINPUT
set sortseed $PILOTSEEDINPUT

sort stratum_id circle_id 
g rand1 = runiform()	
by stratum_id: egen rank1 = rank(rand1), unique // rank1 within strata 
by stratum_id: egen count1 = count(rand1)

**Allocate circles into group of 10 circles by stratified randomization. 
g group = .  
levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	**In the pilot group, we want 6 Lahore A circles and 4 Lahore B circles. 
	if `d' == 5 {
		local num_circles = 6
	}
	if `d' == 6 {
		local num_circles = 4
	}
	local per_bin = floor(`num_circles'/3) 
	replace group = 1 if rank1 >= 1 & rank1 <= `per_bin' & division_id == `d'
}

*Assign additional circle from Lahore B to pilot group
sort stratum_id circle_id
by stratum_id: g temprand = runiform() if _n == 1 
egen temprank = rank(temprand) if division_id == 6, unique // randomly rank strata in Lahore B 
by stratum_id: egen temp = max(temprank) 
replace temprank = temp 
drop temp 

*Find the lowest rank of the unassigned circle that is in the 
*randomly ordered first strata in Lahore B: 
summ rank1 if group == . & temprank == 1 & division_id == 6 , d
local extra_circle = `r(min)'
replace group = 1 if rank1 == `extra_circle' & temprank == 1 & division_id == 6

*Pilot Group Hard-Coded Checks:
count if group == 1
assert `r(N)' == 10 // only 10 circles in pilot
count if group == 1 & division_id == 5
assert `r(N)' == 6 // only 6 circles from Lahore A
count if group == 1 & division_id == 6
assert `r(N)' == 4 // only 4 circles from Lahore B

summ stratum_id if division_id == 5, d
forvalues i = `r(min)'(1)`r(max)'{
	count if group == 1 & stratum_id == `i' 
	assert `r(N)' == 2 // only 2 circles in each strata for Lahore A
}

summ stratum_id if division_id == 6, d
local lahoreB_check = 0 
forvalues i = `r(min)'(1)`r(max)'{
	count if group == 1 & stratum_id == `i' 
	assert `r(N)' >= 1 // at least 1 circle in each strata for Lahore B
	if `r(N)' == 2 {
		local lahoreB_check = `lahoreB_check' + 1 
	}
}
assert `lahoreB_check' == 1 // only one stratum should have 2 circles from Lahore B 

**Create variables for treatment assignment
g treatment = "PILOT GROUP" if group == 1
g lottery_group = treatment 

**Update main_exclude dummy so we can exclude the pilot circles 
replace main_exclude = 1 if group == 1 

**************************************************************************************************

*3. Balance Checks
cap drop ln*
for any gross_dem_c gross_dem_t net_dem_c net_dem_t recov_tot_c recov_tot_t recov_tot_t_12q3: g ln_X = ln(X) 
g ln_change_recovery = ln(recov_tot_t/recov_tot_t_12q3) 

desc ln*, varlist
local sumstatvars "`r(varlist)'"
local number_variables `r(N)' 

forvalues i = 1(1)6{
	g col`i' = . // column placeholders
}

*Calculate summary statistics
local variable_number = 1
foreach var in `sumstatvars'{
	summ `var' if group == 1, d
	replace col1 = `r(mean)' if _n == `variable_number'
	replace col2 = `r(N)' if _n == `variable_number' 
	
	summ `var' if group != 1, d 
	replace col3 = `r(mean)' if _n == `variable_number'
	replace col4 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = (group == 1)
	ttest `var', by(temp) 
	replace col5 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col6 = `r(p)' if _n == `variable_number' 
	
	for any col1 col2 col3 col4 col5 col6: replace X = round(X, 0.001) if _n == `variable_number'
	forvalues i = 1(1)6{
		replace col`i' = round(col`i', 0.001) if _n == `variable_number' 
	}
	local variable_number = `variable_number' + 2
	drop temp
}

**************************************************************************************************

*4. Save files and display 

**Save files 
sort group division_name circle_id
save "Output/Year 1/130726 Lahore PILOT Transfers Randomization Output $PILOTSEEDINPUT", replace

preserve
keep if group == 1 
keep division_id circle_id 
save "Output/Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE $PILOTSEEDINPUT", replace
restore 
