clear all
version 12

**************************************************************************************************

cap cd "$PAKTAX2_RANDOMIZATION"

************************************************************************************************

*1. Open sample from first ballot - Pilot Seed == 150, Main Seed == 1170000
use "Output/Year 1/130726 Lahore Transfers Main Randomization 1170000.dta", clear
assert group != . // assert that no circle has been left unallocated 

************************************************************************************************

*2. Select 4 groups from Lahore for treatment

sort group circle_id 
**Select seed for treatment assignment ballot: 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

sort group circle_id 
by group: g rand3 = runiform() if _n == 1 
egen rank3 = rank(rand3), unique // rank3 within group 
by group: egen temp = max(rank3) 
replace rank3 = temp 
drop temp

**Select groups for treatment.  
g treatment = ""
replace treatment = "CHOICE GROUP 1" if rank3 == 1 
replace treatment = "CHOICE GROUP 2" if rank3 == 2
replace treatment = "CHOICE GROUP 3" if rank3 == 3
replace treatment = "CHOICE GROUP 4" if rank3 == 4
g lottery_group = treatment 

**Select which groups will be ranked by recovery and which groups by demand
sort treatment circle_id
by treatment: g rand4 = runiform() if _n == 1 & treatment != "" 
egen rank4 = rank(rand4), unique // rank4 within treatment group
by treatment: egen temp = max(rank4)
replace rank4 = temp
drop temp

g ranking_method = ""
replace ranking_method = "RECOVERY" if rank4 == 1
replace ranking_method = "RECOVERY" if rank4 == 2
replace ranking_method = "DEMAND" if rank4 == 3
replace ranking_method = "DEMAND" if rank4 == 4

************************************************************************************************

*3. Balance Checks
cap drop ln*
for any gross_dem_c gross_dem_t net_dem_c net_dem_t recov_tot_c recov_tot_t recov_tot_t_12q3: g ln_X = ln(X) 
g ln_change_recovery = ln(recov_tot_t/recov_tot_t_12q3) 

desc ln*, varlist
local sumstatvars "`r(varlist)'"
local number_variables `r(N)' 

forvalues i = 1(1)18{
	g col`i' = . // column placeholders
}

*Calculate summary statistics
local variable_number = 1
foreach var in `sumstatvars'{
	summ `var' if treatment == "CHOICE GROUP 1", d
	replace col1 = `r(mean)' if _n == `variable_number'
	replace col2 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 1"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col3 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col4 = `r(p)' if _n == `variable_number' 
	drop temp
	
	summ `var' if treatment == "CHOICE GROUP 2", d 
	replace col5 = `r(mean)' if _n == `variable_number'
	replace col6 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 2"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col7 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col8 = `r(p)' if _n == `variable_number' 
	drop temp

	summ `var' if treatment == "CHOICE GROUP 3", d 
	replace col9 = `r(mean)' if _n == `variable_number'
	replace col10 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 3"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col11 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col12 = `r(p)' if _n == `variable_number' 
	drop temp

	summ `var' if treatment == "CHOICE GROUP 4", d 
	replace col13 = `r(mean)' if _n == `variable_number'
	replace col14 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 4"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col15 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col16 = `r(p)' if _n == `variable_number' 
	drop temp

	summ `var' if treatment == "", d 
	replace col17 = `r(mean)' if _n == `variable_number'
	replace col18 = `r(N)' if _n == `variable_number' 

	forvalues i = 1(1)18{
		replace col`i' = round(col`i', 0.001) if _n == `variable_number' 
	}
	local variable_number = `variable_number' + 2
}

************************************************************************************************

*4. Save data & and display treatment groups
sort group division_name circle_id
save "Output/Year 1/130803 Lahore Assign Treatment Transfers Randomization Output $SEEDINPUT", replace

