clear all
version 13
cap cd "$PAKTAX2_RANDOMIZATION"

********************************************************************************

*1. CREATE DATASET FOR BALLOT OF NEW DIVISIONS (LAHORE C, DG KHAN, SAHIWAL) 
/*Get current list of circles*/ 
use "Data for Ballot/Punjab Compiled - Quarterly OLD.dta", clear
keep if fiscalyear == 2014 & qtr == 3
keep if inlist(division_name, "DG KHAN", "LAHORE C", "SAHIWAL") 
count // 83
keep division_id division_name circle_id  hr_id   

/*Merge with 2014-Q3 crosswalked data*/ 
merge 1:1 circle_id using "Data for Ballot/2014_q3_crosswalk_OLD.dta", ///
	keepusing(q3_2014_recov_tot_c q3_2014_recov_tot_a) assert(using match) keep(match) nogen

/*Create total recovery variable*/ 
egen q3_2014_recov_tot_t = rowtotal(q3_2014_recov_tot_c q3_2014_recov_tot_a), missing /// stratify on 2014 data

/*Save file*/ 
tempfile current_circles
save "`current_circles'", replace

/*Get list of circles used in last ballot for comparison*/ 
use "Data for Ballot/Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL - Non-Lahore.dta" , clear
keep if inlist(partition_id, 2, 6, 9) 
keep circle_id 
count // 79

/*Merge with current list*/ 
merge 1:1 circle_id using "`current_circles'"
tab _merge

/*Now go through 10 cases that did not merge*/

**first, 200102 + 200200 + 200300 merged into 200302
**so we can drop 200102, 200200, and 200300 
drop if inlist(circle_id, 200102, 200200, 200300) 

**next, there are some brand new circles
**205700, 205800, 701301, 705000, 1005800
**we will keep these 

**the only issue now are circles under litigation
**these have no recovery data so must be excluded
g main_exclude = 1 if q3_2014_recov_tot_t == . // 4 cases 
drop _merge 

/*Generate partition id*/ 
g partition_id = . 
replace partition_id = 1 if inlist(division_name,  "BAHAWALPUR")
replace partition_id = 2 if inlist(division_name,  "DG KHAN") 
replace partition_id = 3 if inlist(division_name,  "FAISALABAD")
replace partition_id = 4 if inlist(division_name,  "GUJRANWALA")
replace partition_id = 5 if inlist(division_name,  "LAHORE A", "LAHORE B")
replace partition_id = 6 if inlist(division_name,  "LAHORE C") 
replace partition_id = 7 if inlist(division_name,  "MULTAN") 
replace partition_id = 8 if inlist(division_name,  "RAWALPINDI")
replace partition_id = 9 if inlist(division_name,  "SAHIWAL")
replace partition_id = 10 if inlist(division_name, "SARGODHA") 
#delimit ; 
label drop partition ; 
label define partition 1 "BAHAWALPUR" 2 "DG KHAN" 3 "FAISALABAD" 4 "GUJRANWALA" 5 "LAHORE"
	6 "LAHORE C" 7 "MULTAN" 8 "RAWALPINDI" 9 "SAHIWAL" 10 "SARGODHA"; 
#delimit cr
label values partition_id partition
assert !missing(partition_id) 

/*Now generate strata*/
drop if main_exclude == 1 // get rid of exclusions 
local numbins 3 // number of bins within each partition 
for any q3_2014_recov_tot_t: g ln_X = ln(X)  // create log total recovery 
local stratify_variable ln_q3_2014_recov_tot_t

levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	xtile bins`d' = `stratify_variable' if division_id == `d', nq(`numbins') // stratify on total recovery 
}
summ division_id, d
g stratum_id = bins`r(min)' // create one variable for all bins 
levelsof division_id if division_id != 1, local(divisions)
foreach d of numlist `divisions'{
	local j = `d' - 1
	local temp = `j'*`numbins'
	replace stratum_id = bins`d' + `temp' if division_id == `d'
}

/*Save file*/ 
order partition_id division_id division_name circle_id  hr_id  stratum_id 
save "Output/Year 1/140804 New Groups Ballot.dta", replace

********************************************************************************

*2. CREATE DATASET FOR BALLOT OF PREVIOUS EXCLUDED CIRCLES  

/*Get strata information for each partition*/ 
use "Data for Ballot/Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL - Non-Lahore.dta", clear

/*Regenerate a strata variable and store cutoffs in variables*/ 
local numbins 3 // number of bins within each partition 
for any recov_tot_t: g ln_X = ln(X)  // create log total recovery 
local stratify_variable ln_recov_tot_t 

levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	xtile new_bins`d' = `stratify_variable' if division_id == `d', nq(`numbins') // stratify on total recovery 
	pctile temp`d' = `stratify_variable' if division_id == `d', nq(`numbins') 
	g bottom`d' = `r(r1)' // store bottom cutoff in variable
	g top`d' = `r(r2)' // store top cutoff in variable 
}
summ division_id, d
g new_stratum_id = new_bins`r(min)' // create one variable for all bins 
levelsof division_id if division_id != 1, local(divisions)
foreach d of numlist `divisions'{
	local j = `d' - 1
	local temp = `j'*`numbins'
	replace new_stratum_id = new_bins`d' + `temp' if division_id == `d'
}
assert new_stratum_id == stratum_id // confirm regeneration is correct 

/*Save tempfile*/
keep division_id top* bottom* 
duplicates drop
tempfile strata
save "`strata'", replace

/*Get excluded circles*/ 
use "Data for Ballot/Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FULL SET - Non-Lahore.dta", clear
keep if main_exclude == 1

/*Number of excluded*/ 
qui count
local num_excluded `r(N)' 

/*Keep relevant variables*/ 
keep division* partition* circle* hr* recov_tot_t 

/*Compare to current data*/
merge 1:1 circle_id using "Data for Ballot/2014_q3_crosswalk_OLD.dta", ///
	keepusing(q3_2013_recov_tot_c q3_2013_recov_tot_a) assert(using match) keep(match) nogen

/*Create total recovery variable*/ 
egen q3_2013_recov_tot_t = rowtotal(q3_2013_recov_tot_c q3_2013_recov_tot_a), missing 

g test = abs(q3_2013_recov_tot_t - recov_tot_t)
summ test, d // very close match (2 obs off by value of 1) so we are okay
drop recov_tot_t test

/*Do not re-include circles with missing recovery*/
drop if q3_2013_recov_tot_t == . // 2 circles 

/*Now assign strata using variable values*/
merge n:1 division_id using "`strata'", keep(match) nogen

for any q3_2013_recov_tot_t: g ln_X = ln(X)  // create log total recovery 
local stratify_variable ln_q3_2013_recov_tot_t
levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	g bins`d' = . 
	replace bins`d' = 1 if `stratify_variable' <= bottom`d' & `stratify_variable' != . & division_id == `d' 
	replace bins`d' = 2 if `stratify_variable' > bottom`d' & `stratify_variable' <= top`d' & `stratify_variable' != .  & division_id == `d' 
	replace bins`d' = 3 if `stratify_variable' > top`d'  & `stratify_variable' != . & division_id == `d' 
}

summ division_id, d
g stratum_id = bins`r(min)' // create one variable for all bins 
levelsof division_id if division_id != 1, local(divisions)
foreach d of numlist `divisions'{
	local j = `d' - 1
	local temp = `j'*`numbins'
	replace stratum_id = bins`d' + `temp' if division_id == `d'
}
drop bins* top* bottom* 
assert !missing(stratum_id) 

/*Dummy variable for excluded circles*/
g excluded = 1 
label var excluded "excluded in Year 1 ballot" 

tempfile excluded_circles
save "`excluded_circles'", replace

/*Append to previously created control groups*/ 
use "Output/Year 1/130829 Other Divisions Assign Treatment Transfers Randomization Output 17921.dta", clear
append using "Output/Year 1/130803 Lahore Assign Treatment Transfers Randomization Output 2100.dta"
keep if missing(treatment) 

append using "`excluded_circles'"
count if missing(group)

/*Save file*/ 
order partition_id division_id division_name circle_id hr_id stratum_id 
drop *rand* *rank* count* num* test* treatment 
save "Output/Year 1/140804 Excluded Circles Ballot.dta", replace
