/*

Tables with Allocation and Preferences for every inspector

Author(s):
	Guillermo Palacios
	
Date created:
	May, 2017
	
*/

******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare input file paths
local survey_coded_data = 		"../Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data.dta"
local pd_section3 =				"../Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 3"
local pd_section4 =				"../Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 4"
local pd_section6 =				"../Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 6"
local pd_section7 =				"../Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 7"
local num_properties = 			"../Data\Cleaned Data\Field Survey\Round 3\Cleaned/Sec9_Title_Count.dta"
local y1_rank = 				"Coded Data/Q4 Ranks.dta" 
local latest_hr_data =			"../Data/Cleaned Data/Administrative Data/Quarterly/FY2016 Q2/FY2016 Q2"
local baseline_analysis = 		"Coded Data/Baseline Preferences analysis data"
local baseline_prefs = 			"Coded Data/Cleaned baseline preferences"
local python_file = 				"Do Files/Paper/clean_allocation_table.py"

******************************************************************************
******************************************************************************
* 1. Data setup
******************************************************************************
******************************************************************************

******************************************************************************
* I. Circle's characteristics
******************************************************************************

* 1.1 Tax base in Year 1

use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear 
drop if litigated == 1
keep if qtr == 4
foreach i in c a t {
gen ln_gross_dem_`i'_growth=ln_gross_dem_`i'-base_ln_gross_dem_`i'
}
drop hr_id
tempfile y1_tax_base
save `y1_tax_base'

* 2. Survey data

	use "`survey_coded_data'", clear
	keep prop_id circle_id tax_payment_total tax_times_payment tax_corruption
	tempfile coded_data
	save `coded_data'
	use "`pd_section3'", clear
	duplicates report prop_id
	merge 1:1 prop_id using "`pd_section4'", nogen
	merge 1:1 prop_id using "`pd_section6'", nogen
	merge 1:1 prop_id using "`pd_section7'", nogen
	merge 1:1 prop_id using "`coded_data'", nogen
	tempfile property_data
	sa `property_data', replace

	foreach var in  elec_pay_person tax_pay_person SEC3_q1a SEC3_q1b {
	recode `var' (2=0)
	}

	drop SEC7_q4_desc 

	rename (SEC3_q1a SEC3_q1b SEC3_q12a_1 SEC3_q12b_1 SEC3_q12c_1) (unof_pay_elec unof_pay_tax corr_elec_dep corr_tax_dep corr_water_dep)
	rename (SEC4_q6_type_1 SEC4_q7_type_1 SEC7_q4) (use_prop use_ground use_real) 

	foreach var in 	use_prop use_real {
	quietly tab `var', gen(`var'_d)
	}

	gen use_prop_res=use_prop_d1 | use_prop_d2 
	gen use_prop_com=use_prop_d3 | use_prop_d4
	gen use_real_res=use_real_d1 
	gen use_real_com=use_real_d2

	*Collapse

	#delimit ;
	collapse (mean) tax_pay_person tax_amt_person unof_pay_tax tax_corruption   corr_tax_dep tax_payment_total tax_goingrate 
			 (mean)	expenditure wages expenditure_hat wages_hat
			 (mean)	use_prop_com use_prop_res use_real_com use_real_res owner_occupied
			 , by (circle_id);
	#delimit cr

	*Labeling variables
	
	label var		  use_real_res "Residential"
	label var 		  use_real_com "Commercial"
	label var		  owner_occupied "Owner occupies the property"

	duplicates report circle_id

	sa `property_data', replace
	

	*Number of properties

	use "`num_properties'", clear
	bys circle_id: gen maxn=_N
	drop if maxn!=1
	keep circle_id S9TITLE_q3
	rename S9TITLE_q3 num_prop
	tempfile number_properties
	save `number_properties'

	use "`property_data'", clear
	merge 1:1 circle_id using "`number_properties'",  nogen

	*Total bribe revenue in Tax Dept

	gen tax_bribe_revenue_total=tax_payment_total*unof_pay_tax*num_prop

	tempfile circles_data
	save `circles_data'

* 3. Merge tax base with characteristics and create last variables

	merge 1:1 circle_id using `y1_tax_base', keep(3) nogen

	*Average property value

	gen av_prop_value=gross_dem_c/num_prop
	summ av_prop_value

	*Unofficial payments (dummy and amount)
	
	gen unof_pay_tax_norm=unof_pay_tax/av_prop_value
	gen tax_payment_total_norm=tax_payment_total/av_prop_value
	
	*Scales

	foreach var in expenditure wages tax_payment_total tax_bribe_revenue_total av_prop_value tax_payment_total_norm {
	gen ln_`var'=ln(`var'+1)
	drop `var'
	rename ln_`var' `var'
	}
	
	*Labels

	label var base_ln_gross_dem_t "Log of tax base (Total)"
	label var base_ln_gross_dem_c "Log of tax base (Current)"
	label var base_ln_gross_dem_a "Log of tax base (Arrears)"
	label var  base_ln_gross_dem_t_growth "Growth in tax base (Total)"
	label var  base_ln_gross_dem_c_growth "Growth in tax base (Current)"
	label var  base_ln_gross_dem_a_growth "Growth in tax base (Arrears)"
	label var base_ln_recov_tot_t "Log of revenue (Total)"
	label var base_ln_recov_tot_c "Log of revenue (Current)"
	label var base_ln_recov_tot_a "Log of revenue (Arrears)"
	label var base_ln_recov_tot_t_growth "Growth in revenue (Total)"
	label var base_ln_recov_tot_c_growth "Growth in revenue (Current)"
	label var base_ln_recov_tot_a_growth "Growth in revenue (Arrears)"
	label var  unof_pay_tax "Any unofficial payment"
	label var tax_corruption  "Degree of corruption in Tax Department"
	label var  expenditure  "Log average p.c. expenditure"
	label var  wages "Average per-capita wage USD"
	label var use_real_com "Properties for commercial use"
	label var  use_real_res "Properties for residential use"
	label var tax_bribe_revenue_total "Total bribe revenue in Tax Department"
	label var av_prop_value "Log of average property value"
	label var tax_payment_total "Log of amount of unofficial payments"
	label var tax_payment_total_norm "Log of unofficial payment rate"
	replace num_prop=num_prop/100
	label var num_prop "Num of properties (in hundreds)"
	label var unof_pay_tax_norm "Any unofficial payment (num of properties by unit of tax base)"	
	rename group_id group_id_circle
	tempfile circles_data
	save `circles_data'
	
foreach t in 1 3 {

********************************************************************************
* II. Ranks for treatment inspectors
********************************************************************************

	use "`y1_rank'", clear
	encode division_name, gen(division_id)
	gen top`t'=rank<=`t'
	keep hr_id division_id group rank top`t'
	tempfile ranks
	save `ranks'

********************************************************************************
* III. Y1 preferences 
********************************************************************************

	clear all

	* List of files in directory
	local pref_files : dir "../Data\Raw Data\Preference Tracking\Data/" files "*.xlsx"

	* Create empty file for Y1 preferences
	tempfile y1_preferences
	save `y1_preferences', emptyok

	* Append all files in directory
	foreach file in `pref_files' { 
	import excel using "../Data\Raw Data\Preference Tracking\Data/`file'", firstrow clear
	destring own_circle, replace // is string in some files, byte in others
	append using `y1_preferences'
	sa `y1_preferences', replace
	}
	ren K comments

	* Create accurate group IDs
	replace division_name = "LAHORE" if inlist(division_name, "LAHORE A", "LAHORE B")
	egen group_id = group(division_name group)

	* Ensure rankings make sense
	bys own_hr_id: egen rank_sum = total(ranking)
	bys own_hr_id: egen rank_count = count(ranking)
	assert rank_sum == (rank_count * (rank_count + 1))/2 if rank_count > 0
	drop rank_sum rank_count

	* Normalize all rankings
	bys own_hr_id: egen rank_count = count(ranking)
	bys own_hr_id: egen max_rank = max(ranking)
	assert max_rank == rank_count if rank_count > 0
	replace ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
	drop rank_count max_rank

	* Keep the data you need
	drop hr_id
	rename own_hr_id hr_id
	sort hr_id ranking
	drop if ranking==.
	gen pref_own=1 if ranking==1 & own_circle==1
	replace pref_own=0 if pref_own==.
	
	keep hr_id circle_id ranking division_name group group_id own_circle
	duplicates report hr_id circle_id
	save `y1_preferences', replace

******************************************************************************	
*IV.Transfers
******************************************************************************	

	use "Coded Data/transfer_file", clear
	keep HRID BallotedCircle CurrentCircle NewCircle Division Group Scheme 
	rename (HRID BallotedCircle CurrentCircle NewCircle Division Group Scheme) (hr_id balloted_circle current_circle new_circle division_name group scheme)
	drop if mi(balloted_circle)
	levelsof division_name
	replace division_name="LAHORE A" if division_name=="LAHORE B"
	tab division_name
	rename new_circle circle_id
	
	* Manually crosswalk current circles
	replace current_circle = 507201 if current_circle == 507300
	replace current_circle = 613610 if current_circle == 613630
	replace current_circle = 614300 if current_circle == 614310
	replace current_circle = 807101 if current_circle == 807103
	replace current_circle = 807102 if current_circle == 807104
	replace current_circle = . 	   if current_circle == 907900
	
	gen own= (current_circle==circle_id)
	tempfile transfers
	save `transfers'

******************************************************************************
* V.Merge and create Master dataset
******************************************************************************

*1. Assign ranking to every inspector in Y1 preferences

	use `y1_preferences', clear
	merge m:1 hr_id using `ranks', keepusing(rank top`t') assert(1 3) keep(3) nogen

*2. Assign circles attributes

	merge m:1 circle_id using `circles_data', keep(1 3)
	gen matched_circle=_m==3
	drop _m
	
	tempfile master
	save `master'
	
******************************************************************************
* VI. Column 1: Y1 preferences for ALL treatment inspectors
******************************************************************************

use `master', clear
preserve
keep if ranking<=`t'
gen R=1
tempfile circles1
save `circles1'
restore
gen R=0
append using `circles1'

tempfile master1
save `master1'
	

******************************************************************************
* VII. Column 2: Y1 preferences for TOP 3 treatment inspectors
******************************************************************************

use `master', clear

keep if top`t'==1
preserve
keep if ranking<=`t'
gen R=1
tempfile circles2
save `circles2'
restore
gen R=0
append using `circles2'

tempfile master2
save `master2'


******************************************************************************
* VIII. Column 3: Allocation
******************************************************************************

use `transfers', clear
keep hr_id circle_id scheme
rename circle_id new_circle_id

merge 1:m hr_id using `master'
sort hr_id circle_id new_circle_id

gen d_new_circle=circle_id==new_circle_id
keep if d_new_circle==1 // Is this correct?

preserve 
keep if top`t'==1
gen R=1
tempfile circles3
save `circles3'
restore
gen R=0
append using `circles3'

tempfile master3
save `master3'

	
******************************************************************************
* IX. Columns 4 & 5: Control Inspectors
******************************************************************************
	
* 0. Where control inspectors currently are

	use "Coded Data/ins_end_q2", clear
	tempfile new_circles
	save `new_circles'
	
  //Circle's characteristics
	merge 1:1 circle_id using `circles_data', keep(3) nogen
	rename circle_id new_circle_id
	save `new_circles', replace
	
* 1. Ranks for control groups based on Demand and Recovery

	use "Coded Data/FY14 Q4 DEMAND Ranks control inspectors", clear
	merge 1:1 hr_id using "Coded Data/FY14 Q4 RECOVERY Ranks control inspectors", assert(3) nogen // SEE WHAT IS GOING ON HERE

* 2. Circles

	merge 1:m hr_id using `new_circles', keep(3)

* 3. Save and modify

	tempfile master_control
	save `master_control'
	
* 4. Column 4 (Recovery)

	use `master_control', clear
	gen top`t'=rank_rec<=`t'
	
	preserve 
	keep if top`t'==1
	gen R=1
	tempfile circles4
	save `circles4'
	restore
	gen R=0
	append using `circles4'

	tempfile master4
	save `master4'

* 5. Column 5 (Demand)

	use `master_control', clear
	gen top`t'=rank_dem<=`t'
	
	preserve 
	keep if top`t'==1
	gen R=1
	tempfile circles5
	save `circles5'
	restore
	gen R=0
	append using `circles5'

	tempfile master5
	save `master5'


******************************************************************************
******************************************************************************
* 2. Regressions
******************************************************************************
******************************************************************************
do "Do Files/programs/all_programs.do"
	
	*1.Column 1

		use `master1', clear
		assert !mi(group_id)
		local nvar 15
		/*
		bys circle_id hr_id: egen max_r=max(R)
		drop if R!=max_r
		*/
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column1) depvars($mylist) indvar(R) n(`nvar')
		columns_rows_mean, results(column99) depvars($mylist) indvar(R) n(`nvar')
		
	*2.Column 2

		use `master2', clear
		assert !mi(group_id)
		
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column2) depvars($mylist) indvar(R) n(`nvar')

	*3.Column 3

		use `master3', clear
		assert !mi(group_id)
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column3) depvars($mylist) indvar(R) n(`nvar')
		
	*3.Column 3a

		use `master3', clear
		assert !mi(group_id)
		keep if scheme=="RECOVERY"
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column3a) depvars($mylist) indvar(R) n(`nvar')

	*3.Column 3B

		use `master3', clear
		assert !mi(group_id)
		keep if scheme=="DEMAND"
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column3b) depvars($mylist) indvar(R) n(`nvar')

	*4.Column 4

		use `master4', clear
		assert !mi(group_id)		
		
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column4) depvars($mylist) indvar(R) n(`nvar')
	
	*5.Column 5

		use `master5', clear
		assert !mi(group_id)
		
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows, results(column5) depvars($mylist) indvar(R) n(`nvar')

	*6.Column 6
		
		use `master3', clear
		cap drop treatment
		gen treatment=1
		gen t=1
		keep if scheme=="RECOVERY"
		replace group_id=group_id+1000
		append using `master4'
		replace treatment=0 if t==.
		assert !mi(group_id)
		gen interaction = treatment*R
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows2, results(column6) depvars($mylist) indvar(interaction R treatment ) n(`nvar')
	
	*7.Column 7
		
		use `master3', clear
		cap drop treatment
		gen treatment=1
		gen t=1
		keep if scheme=="DEMAND"
		replace group_id=group_id+1000
		append using `master5'
		replace treatment=0 if t==.
		assert !mi(group_id)
		gen interaction = treatment*R
		local nvar 15
		global mylist base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value 

		columns_rows2, results(column7) depvars($mylist) indvar(interaction R treatment ) n(`nvar')

******************************************************************************
******************************************************************************
* 3. Tables
******************************************************************************
******************************************************************************  
    
local file = "allocation_preferences_top`t'_paper" 

#delimit ;

esttab column1 column99 column2 column3  column6 column7 using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",  ///
	label booktabs b(3) p(3) eqlabels(none)   /// 
	drop(_cons   ) ///	
	mtitles("\shortstack{All circles\\b / se}"  "\shortstack{All circles\\Mean}" "\shortstack{Top inspectors' circles\\b / se}" "\shortstack{Treated inspectors\\b / se}" "\shortstack{Treatment - Control\\(Revenue)\\b / se}" "\shortstack{Treatment - Control\\(Tax base)\\b / se}") 
	stardrop(base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value)
	stats(N, fmt(0) layout("\multicolumn{1}{c}{@}" ) labels(`"N"' ))
	mgroups("Y1 Preferences (Treatment)" "Allocation" "Difference in allocation",
	pattern(1 0 0 1 1 0 
	)
	prefix(\multicolumn{@span}{c}{)
	suffix(}) span erepeat(\cmidrule(lr){@span})
	)		
	nonotes
	replace
	
	;
# delimit cr

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace
file write tablenote "Columns 1 and 3 present OLS regressions of circles attributes on a dummy variable that takes the value of 1 for circles that were ranked as TOP `t'. Sample consists in all treated circles and treated circles of TOP `t' inspectors, respectively."
file write tablenote " Column 4 shows regressions of circles characteristics on an indicator that takes the value of 1 if the treated inspector that ended up in that circle ranked among the TOP `t' of his group."
file write tablenote " Columns 5 and 6 report the difference in allocation between inspectors in the treatment and control group."
file write tablenote " Inspectors in Column 5 are ranked based on their performance in recovery (growth in recovery rate). In Column 6, based on their performance in demand (growth in tax base)."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

shell python "`python_file'"
  
compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/")    
  

local file = "allocation_preferences_top`t'_paper_app" 

#delimit ;

esttab column1 column2 column3  column6 column7 using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",  ///
	label booktabs b(3) p(3) eqlabels(none)  collabels("\multicolumn{1}{c}{b / se}" "\multicolumn{1}{c}{Mean}") ///
	drop(_cons   ) ///
	mtitles("All circles" "Top inspectors' circles" "Treated inspectors" "\shortstack{Treatment - Control \\ (Revenue)}" "\shortstack{Treatment - Control \\ (Tax base)}" ) 
	cells("b(fmt(3)star) mean(fmt(3))" "se(fmt(3)par)") ///
	stardrop(base_ln_gross_dem_c base_ln_gross_dem_a base_ln_gross_dem_c_growth base_ln_gross_dem_a_growth base_ln_recov_tot_c base_ln_recov_tot_a base_ln_recov_tot_c_growth base_ln_recov_tot_a_growth unof_pay_tax tax_payment_total_norm expenditure  use_real_com use_real_res num_prop av_prop_value)
	stats(N, fmt(0) layout("\multicolumn{1}{c}{@}" ) labels(`"N"' ))
	mgroups("Y1 Preferences (Treatment)" "Allocation" "Difference in allocation",
	pattern(1 0 1 1 0 
	)
	prefix(\multicolumn{@span}{c}{)
	suffix(}) span erepeat(\cmidrule(lr){@span})
	)		
	replace
	
	;
# delimit cr

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace
file write tablenote "Columns 1 and 2 present OLS regressions of circles attributes on a dummy variable that takes the value of 1 for circles that were ranked as TOP `t'. Sample consists in all treated circles and treated circles of TOP `t' inspectors, respectively."
file write tablenote " Column 3 shows regressions of circles characteristics on an indicator that takes the value of 1 if the treated inspector that ended up in that circle ranked among the TOP `t' of his group."
file write tablenote " Columns 4 and 5 report the difference in allocation between inspectors in the treatment and control group."
file write tablenote " Inspectors in Column 4 are ranked based on their performance in recovery (growth in recovery rate). In Column 5, based on their performance in demand (growth in tax base)."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/")    

}

